@@ -1,19 +1,21 @@
-from turtleAgent import Turtle
-from envBuilder import *
+from .turtleAgent import Turtle
+from .envBuilder import *
 # @DEBUG from .turtleAgent import Turtle
 # @DEBUG ffrom .envBuilder import *
 import time
 import random
 
 class Game:
-    def __init__(self, env, gui):
-        self.env = env
+    def __init__(self, envName, gui):
+        self.envName = envName
         self.gui = gui
         pass
 
     def start(self):
         # Instanciate the envBuilder
-        envbuilder = EnvBuilder(name=self.env, gui=self.gui)
+        envbuilder = EnvBuilder(name=self.envName, gui=self.gui)
         # creates the grid and the turtle
         agent, env = envbuilder.build_grid()
-        return Turtle(agent, env)        
\ No newline at end of file
+        return Turtle(agent, env)
+
+
